package com.example.user.myapp;

import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.content.IntentFilter;
import android.os.Handler;
import android.support.v4.content.LocalBroadcastManager;
import android.support.v7.app.AppCompatActivity;
import android.os.Bundle;
import android.widget.TextView;

import java.util.ArrayList;
import java.util.Calendar;
import java.util.Date;

public class DisplayMessageActivity extends AppCompatActivity {

    private Handler handlerCoil;
    private Handler handlerInputRegister;

    private GlobalState state;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_display_message);

        // listener
        LocalBroadcastManager.getInstance(this).registerReceiver(coilMessageReceiver, new IntentFilter("readOnlyCoil"));
        LocalBroadcastManager.getInstance(this).registerReceiver(discreteInputMessageReceiver, new IntentFilter("readOnlyDiscreteInput"));
        LocalBroadcastManager.getInstance(this).registerReceiver(inputRegisterMessageReceiver, new IntentFilter("readOnlyInputRegister"));


        state = (GlobalState) getApplicationContext();

        //handler
        handlerCoil = new Handler();
        handlerCoil.post(refreshCoil);

        handlerInputRegister = new Handler();
        handlerInputRegister.post(refreshInputRegister);
    }

    Runnable refreshCoil = new Runnable() {
        @Override
        public void run() {
        Intent serviceIntent = new Intent(getApplicationContext(), MyIntentService.class);
        serviceIntent.setAction("read.coil");
        serviceIntent.putExtra("extra.ip.address", state.getIpAddress());
        serviceIntent.putExtra("extra.ip.port", state.getPort());
        serviceIntent.putExtra("extra.ref", state.getCoilRef());
        serviceIntent.putExtra("extra.count", state.getCoilCount());
        serviceIntent.putExtra("extra.intent.name", "readOnlyCoil");
        getApplicationContext().startService(serviceIntent);

        handlerCoil.postDelayed(this, 10000);
        }
    };

    Runnable refreshDiscretInput = new Runnable() {
        @Override
        public void run() {
            // TODO Auto-generated method stub
            TextView textView = findViewById(R.id.textView1);
            Date currentTime = Calendar.getInstance().getTime();
            textView.setText(new Double(Math.random()).toString());
            handlerCoil.postDelayed(this, 1000);
        }
    };

    Runnable refreshInputRegister = new Runnable() {
        @Override
        public void run() {
            // TODO Auto-generated method stub
            TextView textView = findViewById(R.id.textView1);
            Date currentTime = Calendar.getInstance().getTime();
            textView.setText(new Double(Math.random()).toString());
            handlerCoil.postDelayed(this, 2000);
        }
    };

    // on message receive, update the view with values
    private BroadcastReceiver coilMessageReceiver = new BroadcastReceiver() {
        @Override
        public void onReceive(Context context, Intent intent) {
            String action = intent.getAction();
            Bundle bundle = intent.getExtras();
            boolean[] booleanArray = bundle.getBooleanArray("coilValues");

            TextView textView1 = findViewById(R.id.textView1);
            textView1.setText(new Boolean(booleanArray[0]).toString());

            TextView textView2 = findViewById(R.id.textView2);
            textView2.setText(new Boolean(booleanArray[1]).toString());

            TextView textView3 = findViewById(R.id.textView3);
            textView3.setText(new Boolean(booleanArray[2]).toString());

            TextView textView4 = findViewById(R.id.textView4);
            textView4.setText(new Boolean(booleanArray[3]).toString());

       /*     TextView textView5 = findViewById(R.id.textView5);
            textView5.setText(new Boolean(booleanArray[4]).toString());

            TextView textView6 = findViewById(R.id.textView6);
            textView6.setText(new Boolean(booleanArray[5]).toString());

            TextView textView7 = findViewById(R.id.textView7);
            textView7.setText(new Boolean(booleanArray[6]).toString());

            TextView textView8 = findViewById(R.id.textView8);
            textView8.setText(new Boolean(booleanArray[7]).toString()); */
        }
    };

    private BroadcastReceiver inputRegisterMessageReceiver = new BroadcastReceiver() {
        @Override
        public void onReceive(Context context, Intent intent) {
            String action = intent.getAction();
            Bundle bundle = intent.getExtras();
            ArrayList<Integer> integers = bundle.getIntegerArrayList("irValues");

            TextView textView9 = findViewById(R.id.textView9);
            textView9.setText(integers.get(0).toString());
        }
    };

    private BroadcastReceiver discreteInputMessageReceiver = new BroadcastReceiver() {
        @Override
        public void onReceive(Context context, Intent intent) {

        }
    };
}
